reeeeeeeeee
===========

Inspired by the `ls command <https://github.com/mtoyoda/sl>`_, reeeeeeeeee lets you vent your frustrations on the command line

|REEEEEEEEEEEEEEEEEEEEEEEE|

.. |REEEEEEEEEEEEEEEEEEEEEEEE| image:: https://i.imgur.com/NbDGVui.gif
